#!/bin/bash

read_char() {
  stty -icanon -echo
  eval "$1=\$(dd bs=1 count=1 2>/dev/null)"
  stty icanon echo
}

create_dir() {
if [ ! -d "$1" ]; then
if [ "$gksu_flag" = 1 ]; then
gksu -- mkdir "-p" $1
else
sudo mkdir "-p" $1
fi
fi
}

# See if the enduser unzipped the 44khz or 48khz (or both) zip archive containing
# the sound files. First check for a 44KHz or 48KHz dir
khz44=0
khz48=0
if [ -d "${SCRIPT_DIR}/44KHz" ]; then
khz44=1
fi
if [ -d "${SCRIPT_DIR}/48KHz" ]; then
khz48=1
fi

#==============================
# If he downloaded both the 44khz and 48khz versions, ask about installing both
if [[ $khz44 == 1 && $khz48 == 1 ]]; then
if [ "$gksu_flag" = 1 ]; then
ans=$(zenity --info --ellipsize --title 'No Budget Instruments' \
      --text "You seem to have downloaded the ${section_name} sound files\nfor both 44100 KHz sample rate, as well as 48000 KHz.\n\nYou don't need both sets of sound files unless you want to record your\naudio tracks at either rate. So, do you want to install both sets?" \
      --ok-label "Both" \
      --extra-button "44.1 KHz" \
      --extra-button "48 KHz" \
      )
if [ "$ans" = "44.1 KHz" ]; then
khz48=0
elif [ "$ans" = "48 KHz" ]; then
khz44=0
fi
else
clear
echo "You seem to have downloaded the ${section_name} sound files for both"
echo "44100 KHz sample rate, as well as 48000 KHz. You don't need"
echo "both sets of sound files unless you want to record your audio"
echo "tracks at either rate. So, do you want to install both sets?"
echo
echo -e "Press \033[1mEnter\033[0m for both, or press \033[1m1\033[0m or \033[1m2\033[0m for"
echo "either 44100 khz or 48000 khz respectively."
read_char ANS
if [ "$ANS" = "1" ]; then
khz48=0
fi
if [ "$ANS" = "2" ]; then
khz44=0
fi
fi
fi

# If nothing, quit
if [[ "$khz44" == 0 && "$khz48" == 0 ]]; then
if [ "$gksu_flag" = 1 ]; then
zenity --info --ellipsize --text="You must download the zip archive containing the\n${section_name} sound files. If you play back your audio tracks at 44100 KHz sample\nrate, then you should download ${zip_name44}.\n\nIf you play back your audio tracks at 48000 KHz, then you should download\n${zip_name48} instead.\n\nIf you use both rates, then download both.\n\nUnzip the files to the same folder as this installer (for example,\nyour home directory). Afterward, run this installer again."
else
clear
echo "You must download the zip archive containing the ${section_name}"
echo "sound files. If you play back your audio tracks at 44100 KHz"
echo -e "sample rate, then you should download \033[1m${zip_name44}\033[0m."
echo  "If you play back your audio tracks at 48000 KHz, then you"
echo -e "should download \033[1m${zip_name48}\033[0m instead. If you use"
echo "both rates, then download both files. Unzip the files to the same folder"
echo "as this installer (for example, your home directory). Afterward,"
echo "run this installer again. See you later..."
fi
exit
fi

# See if install for all users, or only current user
wavedestdir="/usr/share"
AllUsers=1
if [ "$gksu_flag" = 1 ]; then
ans=$(zenity --info --ellipsize --title 'No Budget Instruments' --text "Do you wish to install the plugins for all users, or only the current user?" --ok-label "All users" --extra-button "Just me")
if [ "$ans" = "Just me" ]; then
AllUsers=0
wavedestdir="$HOME"
fi
else
clear
echo -e "Do you wish to install the plugins for all users, or only the current user?\n\n"
echo -e "Press \033[1mEnter\033[0m for all users, or any other key for the current user."
echo
read_char ANS
if [[ -n "$ANS" ]]; then
AllUsers=0
wavedestdir="$HOME"
fi
fi

# Create the NoBudget directory for the wave files
wavedestdir="${wavedestdir}/NoBudget"
if [ "$SCRIPT_DIR" != "$wavedestdir" ]; then

if [ "$gksu_flag" = 1 ]; then
zenity --question --ellipsize --text="I will now create the folder named ${wavedestdir} to copy the\nsound files. You may be asked to enter your sudo password.\nClick Yes to proceed, or No to cancel."
ANS=$?
if [ "$ANS" != 0 ]; then
exit
fi
else
clear
echo -e "I will now create the folder named \033[1m${wavedestdir}\033[0m to copy\nthe sound files. You may be asked to enter your sudo password.\n\n"
echo -e "Press \033[1mEnter\033[0m to continue."
echo
read_char ANS
fi


if [ ! -d "$wavedestdir" ]; then
if [ "$gksu_flag" = 1 ]; then

if [[ $khz44 == 1 ]]; then
gksu -- mkdir --mode=775 -p "${wavedestdir}/44KHz"
fi
if [[ $khz48 == 1 ]]; then
gksu -- mkdir --mode=775 -p "${wavedestdir}/48KHz"
fi
else
if [[ $khz44 == 1 ]]; then
sudo mkdir --mode=775 -p "${wavedestdir}/44KHz"
fi
if [[ $khz48 == 1 ]]; then
sudo mkdir --mode=775 -p "${wavedestdir}/48KHz"
fi
fi
if [ ! -d "$wavedestdir" ]; then
if [ "$gksu_flag" = 1 ]; then
zenity --error --ellipsize --text="There appears to be a problem creating ${wavedestdir}.\n\nSorry, I can't continue."
else
clear
echo -e "There appears to be a problem creating ${wavedestdir}.\nSorry, I can't continue."
fi
exit
fi
fi

else
khz48=0
khz44=0
fi
