#!/bin/bash

write_output() {
chan="L"
channame="Left"
if [ "$1" = 1 ]; then
chan="R"
channame="Right"
fi
printf " a lv2:OutputPort, lv2:AudioPort ;\n\tlv2:index $1 ;\n\tlv2:name \"Audio Out ${chan}\" ;\n\tlv2:symbol \"AUDIO_$2\" ;\n\tlv2:designation pg:${channame} ;\n ] ,\n"
}

create_dir() {
if [ ! -d "$1" ]; then
if [ "$gksu_flag" = 1 ]; then
gksu -- mkdir "--mode=775" "-p" "$1"
echo "creating" $1
else
sudo mkdir "--mode=775" "-p" "$1"
fi
fi
}

# Create the plugin dir
temprootdir="/usr/local/lib/lv2"
if [ "${AllUsers}" = 0 ]; then
temprootdir="${HOME}/.lv2"
fi
wave_destdir="${temprootdir}/${wave_dir_name}.lv2"
create_dir $wave_destdir

# Create the manifest.ttl
printf "@prefix lv2: <http://lv2plug.in/ns/lv2core#> .\n@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .\n\n<http://"${wave_dir_name}">\n \
a lv2:Plugin, lv2:InstrumentPlugin ;\n lv2:binary <"${wave_dir_name}".so> ;\n rdfs:seeAlso <"${wave_dir_name}".ttl> ." > ${SCRIPT_DIR}/manifest.ttl

# Create the plugin .ttl
{
printf "@prefix lv2: <http://lv2plug.in/ns/lv2core#> .\n@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .\n\
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .\n@prefix doap: <http://usefulinc.com/ns/doap#> .\n\
@prefix foaf: <http://xmlns.com/foaf/0.1/> .\n@prefix atom: <http://lv2plug.in/ns/ext/atom#> .\n\
@prefix size: <http://lv2plug.in/ns/ext/resize-port#> .\n@prefix pg: <http://lv2plug.in/ns/ext/port-groups> .\n"
if [ "${SettingsWindow}" = "" ]; then
printf "@prefix ui: <http://lv2plug.in/ns/extensions/ui#> .\n\
\n<http://${wave_dir_name}_ui>\n a ui:X11UI ;\n ui:binary <${wave_dir_name}_ui.so> ;\n lv2:requiredFeature <http://lv2plug.in/ns/ext/urid#map> ;\n\
 ui:portNotification [\n\tui:plugin <http://${wave_dir_name}> ;\n\tlv2:symbol \"FROM_DSP\" ;\n\tui:notifyType atom:Blank\n ] .\n"
fi
printf "\n<http://${wave_dir_name}>\n a lv2:Plugin, lv2:InstrumentPlugin ;\n doap:name \"${wave_dir_name}\" ;\n doap:maintainer [ foaf:name \"Jeff Glatt\" ] ;\n\
 lv2:optionalFeature lv2:hardRTCapable ;\n lv2:requiredFeature <http://lv2plug.in/ns/ext/urid#map> ;\n"
if [ "${SettingsWindow}" = "" ]; then
printf " ui:ui <http://${wave_dir_name}_ui> ;\n"
fi
printf " lv2:port [\n"
write_output 0 1
printf " [\n"
write_output 1 2
printf " [\n a lv2:InputPort, atom:AtomPort ;\n atom:bufferType atom:Sequence ;\n\tlv2:index 2 ;\n\tlv2:name \"MIDI In\" ;\n\tlv2:symbol \"MIDI_IN\" ;\n\tatom:supports <http://lv2plug.in/ns/ext/midi#MidiEvent> ;\n"
if [ "$SettingsWindow" = "" ]; then
printf " ] ,\n [\n a lv2:OutputPort, atom:AtomPort ;\n\tatom:bufferType atom:Sequence ;\n\tlv2:designation lv2:control ;\n\tlv2:index 3 ;\n\tlv2:name \"DSP to GUI\" ;\n\tlv2:symbol \"TO_GUI\" ;\n"
fi
printf " ] ."
} > ${SCRIPT_DIR}/${wave_dir_name}.ttl

if [ "$gksu_flag" = 1 ]; then
gksu -- cp "-f" "${SCRIPT_DIR}/manifest.ttl" "${wave_destdir}/manifest.ttl"
gksu -- cp "-f" "${SCRIPT_DIR}/${wave_dir_name}.ttl" "${wave_destdir}/${wave_dir_name}.ttl"
gksu -- cp "--preserve=timestamps" "-f" "${SCRIPT_DIR}/libs/${wave_dir_name}.so" "${wave_destdir}"
if [ "${SettingsWindow}" = "" ]; then
gksu -- cp "--preserve=timestamps" "-f" "${SCRIPT_DIR}/libs/${wave_dir_name}_ui.so" "${wave_destdir}"
fi
gksu -- chmod -R 775 "${wave_destdir}"
else
sudo cp "-f" "${SCRIPT_DIR}/manifest.ttl" "${wave_destdir}/manifest.ttl"
sudo cp "-f" "${SCRIPT_DIR}/${wave_dir_name}.ttl" "${wave_destdir}/${wave_dir_name}.ttl"
sudo cp "--preserve=timestamps" "-f" "${SCRIPT_DIR}/libs/${wave_dir_name}.so" "${wave_destdir}"
if [ "${SettingsWindow}" = "" ]; then
sudo cp "--preserve=timestamps" "-f" "${SCRIPT_DIR}/libs/${wave_dir_name}_ui.so" "${wave_destdir}"
fi
sudo chmod -R 775 "${wave_destdir}"
fi

rm "${SCRIPT_DIR}/${wave_dir_name}.ttl"
rm "${SCRIPT_DIR}/manifest.ttl"

if [ ! -f "${wave_destdir}/${wave_dir_name}.so" ]; then
if [ "$gksu_flag" = 1 ]; then
zenity --error --ellipsize --text="There appears to be a problem installing the plugin\nto ${wave_destdir}.\n\nSorry, I can't continue."
ANS=$?
else
echo -e "\n\nThere appears to be a problem installing the plugin to ${wave_destdir}.\n\nSorry, I can't continue."
fi
exit
fi
